@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,8 +21,6 @@
 #ifndef __FILE_ROLLER_PLUGIN_H__
 #define __FILE_ROLLER_PLUGIN_H__
 
-G_BEGIN_DECLS
-
 #define FILE_ROLLER_PLUGIN(obj) \
     GTK_CHECK_CAST (obj, file_roller_plugin_get_type (), FileRollerPlugin)
 #define FILE_ROLLER_PLUGIN_CLASS(klass) \
@@ -47,11 +45,8 @@ struct _FileRollerPluginClass
     GnomeCmdPluginClass parent_class;
 };
 
-
 GtkType file_roller_plugin_get_type ();
 
 GnomeCmdPlugin *file_roller_plugin_new ();
 
-G_END_DECLS
-
 #endif //__FILE_ROLLER_PLUGIN_H__
