@@ -1698,7 +1698,7 @@ static gboolean on_new_textfile_ok (GnomeCmdStringDialog *string_dialog, const g
     g_free (escaped_filepath);
 
     if (cmd)
-        run_command (cmd, FALSE);
+        run_command (cmd);
 
     return TRUE;
 }
@@ -1749,6 +1749,11 @@ void gnome_cmd_file_selector_show_new_textfile_dialog (GnomeCmdFileSelector *fs)
                                           (GnomeCmdStringDialogCallback) on_new_textfile_ok, fs);
     g_return_if_fail (GNOME_CMD_IS_DIALOG (dialog));
 
+    GnomeCmdFile *f = fs->file_list()->get_selected_file();
+
+    if (f)
+        gnome_cmd_string_dialog_set_value (GNOME_CMD_STRING_DIALOG (dialog), 0, f->info->name);
+
     gtk_widget_ref (dialog);
     gtk_widget_show (dialog);
 }
